"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "type"


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an event type. You cannot delete an event type that is used in a detector or a model. When you delete an entity type, Amazon Fraud Detector permanently deletes that entity type and the data is no longer stored in Amazon Fraud Detector.

    Args:
        name(str): The name of the event type to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.event.type_.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.event.type.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="delete_event_type",
        op_kwargs={"name": name},
    )


async def get_all(
    hub, ctx, name: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets all event types or a specific event type if name is provided. This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from the GetEventTypesResponse as part of your request. A null pagination token fetches the records from the beginning.

    Args:
        name(str, optional): The name. Defaults to None.
        next_token(str, optional): The next token for the subsequent request. Defaults to None.
        max_results(int, optional): The maximum number of objects to return for the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.event.type_.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.event.type.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_event_types",
        op_kwargs={"name": name, "nextToken": next_token, "maxResults": max_results},
    )


async def put(
    hub,
    ctx,
    name: str,
    event_variables: List,
    entity_types: List,
    description: str = None,
    labels: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates an event type. An event is a business activity that is evaluated for fraud risk. With Amazon Fraud Detector, you generate fraud predictions for events. An event type defines the structure for an event sent to Amazon Fraud Detector. This includes the variables sent as part of the event, the entity performing the event (such as a customer), and the labels that classify the event. Example event types include online payment transactions, account registrations, and authentications.

    Args:
        name(str): The name.
        description(str, optional): The description of the event type. Defaults to None.
        event_variables(List): The event type variables.
        labels(List, optional): The event type labels. Defaults to None.
        entity_types(List): The entity type for the event type. Example entity types: customer, merchant, account.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.event.type_.put(
                ctx, name=value, event_variables=value, entity_types=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.event.type.put name=value, event_variables=value, entity_types=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="put_event_type",
        op_kwargs={
            "name": name,
            "description": description,
            "eventVariables": event_variables,
            "labels": labels,
            "entityTypes": entity_types,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    conference_provider_name: str,
    conference_provider_type: str,
    meeting_setting: Dict,
    ip_dial_in: Dict = None,
    pstn_dial_in: Dict = None,
    client_request_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a new conference provider under the user's AWS account.

    Args:
        conference_provider_name(str): The name of the conference provider.
        conference_provider_type(str): Represents a type within a list of predefined types.
        ip_dial_in(Dict, optional): The IP endpoint and protocol for calling. Defaults to None.
        pstn_dial_in(Dict, optional): The information for PSTN conferencing. Defaults to None.
        meeting_setting(Dict): The meeting settings for the conference provider.
        client_request_token(str, optional): The request token of the client. Defaults to None.
        tags(List, optional): The tags to be added to the specified resource. Do not provide system tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.conference.provider.create(
                ctx,
                conference_provider_name=value,
                conference_provider_type=value,
                meeting_setting=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.conference.provider.create conference_provider_name=value, conference_provider_type=value, meeting_setting=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="create_conference_provider",
        op_kwargs={
            "ConferenceProviderName": conference_provider_name,
            "ConferenceProviderType": conference_provider_type,
            "IPDialIn": ip_dial_in,
            "PSTNDialIn": pstn_dial_in,
            "MeetingSetting": meeting_setting,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, conference_provider_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a conference provider.

    Args:
        conference_provider_arn(str): The ARN of the conference provider.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.conference.provider.delete(
                ctx, conference_provider_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.conference.provider.delete conference_provider_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_conference_provider",
        op_kwargs={"ConferenceProviderArn": conference_provider_arn},
    )


async def get(hub, ctx, conference_provider_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets details about a specific conference provider.

    Args:
        conference_provider_arn(str): The ARN of the newly created conference provider.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.conference.provider.get(
                ctx, conference_provider_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.conference.provider.get conference_provider_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_conference_provider",
        op_kwargs={"ConferenceProviderArn": conference_provider_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists conference providers under a specific AWS account.

    Args:
        next_token(str, optional): The tokens used for pagination. Defaults to None.
        max_results(int, optional): The maximum number of conference providers to be returned, per paginated calls. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.conference.provider.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.conference.provider.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="list_conference_providers",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub,
    ctx,
    conference_provider_arn: str,
    conference_provider_type: str,
    meeting_setting: Dict,
    ip_dial_in: Dict = None,
    pstn_dial_in: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing conference provider's settings.

    Args:
        conference_provider_arn(str): The ARN of the conference provider.
        conference_provider_type(str): The type of the conference provider.
        ip_dial_in(Dict, optional): The IP endpoint and protocol for calling. Defaults to None.
        pstn_dial_in(Dict, optional): The information for PSTN conferencing. Defaults to None.
        meeting_setting(Dict): The meeting settings for the conference provider.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.conference.provider.update(
                ctx,
                conference_provider_arn=value,
                conference_provider_type=value,
                meeting_setting=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.conference.provider.update conference_provider_arn=value, conference_provider_type=value, meeting_setting=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="update_conference_provider",
        op_kwargs={
            "ConferenceProviderArn": conference_provider_arn,
            "ConferenceProviderType": conference_provider_type,
            "IPDialIn": ip_dial_in,
            "PSTNDialIn": pstn_dial_in,
            "MeetingSetting": meeting_setting,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_id: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists tags that are attached to the specified resource. You can attach tags to the following resources in AWS Organizations.   AWS account   Organization root   Organizational unit (OU)   Policy (any type)   This operation can be called only from the organization's management account or by a member account that is a delegated administrator for an AWS service.

    Args:
        resource_id(str): The ID of the resource with the tags to list. You can specify any of the following taggable resources.   AWS account – specify the account ID number.   Organizational unit – specify the OU ID that begins with ou- and looks similar to: ou-1a2b-34uvwxyz     Root – specify the root ID that begins with r- and looks similar to: r-1a2b     Policy – specify the policy ID that begins with p- andlooks similar to: p-12abcdefg3    .
        next_token(str, optional): The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.tags_for_resource.list(ctx, resource_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.tags_for_resource.list resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceId": resource_id, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, instance_id: str, iam_role: str) -> Dict:
    r"""
    **Autogenerated function**

    Changes the Identity and Access Management (IAM) role that is assigned to the on-premises instance or virtual machines (VM). IAM roles are first assigned to these hybrid instances during the activation process. For more information, see CreateActivation.

    Args:
        instance_id(str): The ID of the managed instance where you want to update the role.
        iam_role(str): The IAM role you want to assign or change.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.managed_instance.role.update(
                ctx, instance_id=value, iam_role=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.managed_instance.role.update instance_id=value, iam_role=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="update_managed_instance_role",
        op_kwargs={"InstanceId": instance_id, "IamRole": iam_role},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the tags from the bucket. To use this operation, you must have permission to perform the s3:PutBucketTagging action. By default, the bucket owner has this permission and can grant this permission to others.  The following operations are related to DeleteBucketTagging:    GetBucketTagging     PutBucketTagging

    Args:
        bucket(str): The bucket that has the tag set to be removed.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.tagging.delete(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.tagging.delete bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_bucket_tagging",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the tag set associated with the bucket. To use this operation, you must have permission to perform the s3:GetBucketTagging action. By default, the bucket owner has this permission and can grant this permission to others.  GetBucketTagging has the following special error:   Error code: NoSuchTagSetError    Description: There is no tag set associated with the bucket.     The following operations are related to GetBucketTagging:    PutBucketTagging     DeleteBucketTagging

    Args:
        bucket(str): The name of the bucket for which to get the tagging information.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.tagging.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.tagging.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_tagging",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    tagging: Dict,
    content_md5: str = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets the tags for a bucket. Use tags to organize your AWS bill to reflect your own cost structure. To do this, sign up to get your AWS account bill with tag key values included. Then, to see the cost of combined resources, organize your billing information according to resources with the same tag key values. For example, you can tag several resources with a specific application name, and then organize your billing information to see the total cost of that application across several services. For more information, see Cost Allocation and Tagging and Using Cost Allocation in Amazon S3 Bucket Tags.   When this operation sets the tags for a bucket, it will overwrite any current tags the bucket already has. You cannot use this operation to add tags to an existing list of tags.  To use this operation, you must have permissions to perform the s3:PutBucketTagging action. The bucket owner has this permission by default and can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources.  PutBucketTagging has the following special errors:   Error code: InvalidTagError    Description: The tag provided was not a valid tag. This error can occur if the tag did not pass input validation. For information about tag restrictions, see User-Defined Tag Restrictions and AWS-Generated Cost Allocation Tag Restrictions.     Error code: MalformedXMLError    Description: The XML provided does not match the schema.     Error code: OperationAbortedError     Description: A conflicting conditional action is currently in progress against this resource. Please try again.     Error code: InternalError    Description: The service was unable to apply the provided tag to the bucket.     The following operations are related to PutBucketTagging:    GetBucketTagging     DeleteBucketTagging

    Args:
        bucket(str): The bucket name.
        content_md5(str, optional): The base64-encoded 128-bit MD5 digest of the data. You must use this header as a message integrity check to verify that the request body was not corrupted in transit. For more information, see RFC 1864. For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        tagging(Dict): Container for the TagSet and Tag elements.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.tagging.put(ctx, bucket=value, tagging=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.tagging.put bucket=value, tagging=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_tagging",
        op_kwargs={
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "Tagging": tagging,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, delivery_channel_names: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the current status of the specified delivery channel. If a delivery channel is not specified, this action returns the current status of all delivery channels associated with the account.  Currently, you can specify only one delivery channel per region in your account.

    Args:
        delivery_channel_names(List, optional): A list of delivery channel names. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.delivery_channel.status.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.delivery_channel.status.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_delivery_channel_status",
        op_kwargs={"DeliveryChannelNames": delivery_channel_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    billing_group_name: str,
    billing_group_properties: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a billing group.

    Args:
        billing_group_name(str): The name you wish to give to the billing group.
        billing_group_properties(Dict, optional): The properties of the billing group. Defaults to None.
        tags(List, optional): Metadata which can be used to manage the billing group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.billing_group.create(ctx, billing_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.billing_group.create billing_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_billing_group",
        op_kwargs={
            "billingGroupName": billing_group_name,
            "billingGroupProperties": billing_group_properties,
            "tags": tags,
        },
    )


async def delete(
    hub, ctx, billing_group_name: str, expected_version: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the billing group.

    Args:
        billing_group_name(str): The name of the billing group.
        expected_version(int, optional): The expected version of the billing group. If the version of the billing group does not match the expected version specified in the request, the DeleteBillingGroup request is rejected with a VersionConflictException. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.billing_group.delete(ctx, billing_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.billing_group.delete billing_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_billing_group",
        op_kwargs={
            "billingGroupName": billing_group_name,
            "expectedVersion": expected_version,
        },
    )


async def describe(hub, ctx, billing_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a billing group.

    Args:
        billing_group_name(str): The name of the billing group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.billing_group.describe(ctx, billing_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.billing_group.describe billing_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_billing_group",
        op_kwargs={"billingGroupName": billing_group_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    name_prefix_filter: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the billing groups you have created.

    Args:
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per request. Defaults to None.
        name_prefix_filter(str, optional): Limit the results to billing groups whose names have the given prefix. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.billing_group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.billing_group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_billing_groups",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "namePrefixFilter": name_prefix_filter,
        },
    )


async def update(
    hub,
    ctx,
    billing_group_name: str,
    billing_group_properties: Dict,
    expected_version: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates information about the billing group.

    Args:
        billing_group_name(str): The name of the billing group.
        billing_group_properties(Dict): The properties of the billing group.
        expected_version(int, optional): The expected version of the billing group. If the version of the billing group does not match the expected version specified in the request, the UpdateBillingGroup request is rejected with a VersionConflictException. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.billing_group.update(
                ctx, billing_group_name=value, billing_group_properties=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.billing_group.update billing_group_name=value, billing_group_properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_billing_group",
        op_kwargs={
            "billingGroupName": billing_group_name,
            "billingGroupProperties": billing_group_properties,
            "expectedVersion": expected_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, scope: str, next_marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an array of managed rule groups that are available for you to use. This list includes all Amazon Web Services Managed Rules rule groups and the Marketplace managed rule groups that you're subscribed to.

    Args:
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        next_marker(str, optional): When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request. Defaults to None.
        limit(int, optional): The maximum number of objects that you want WAF to return for this request. If more objects are available, in the response, WAF provides a NextMarker value that you can use in a subsequent call to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.available_managed_rule_group.list_all(ctx, scope=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.available_managed_rule_group.list_all scope=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="list_available_managed_rule_groups",
        op_kwargs={"Scope": scope, "NextMarker": next_marker, "Limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, arn: str, deletion_protected: bool, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Update deletion protection to either allow or deny deletion of the final Region in a replication set.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the replication set you're updating.
        client_token(str, optional): A token ensuring that the action is called only once with the specified details. Defaults to None.
        deletion_protected(bool): Details if deletion protection is enabled or disabled in your account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.deletion_protection.update(
                ctx, arn=value, deletion_protected=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.deletion_protection.update arn=value, deletion_protected=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="update_deletion_protection",
        op_kwargs={
            "arn": arn,
            "clientToken": client_token,
            "deletionProtected": deletion_protected,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    configuration: Dict = None,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a workgroup with the specified name.

    Args:
        name(str): The workgroup name.
        configuration(Dict, optional): The configuration for the workgroup, which includes the location in Amazon S3 where query results are stored, the encryption configuration, if any, used for encrypting query results, whether the Amazon CloudWatch Metrics are enabled for the workgroup, the limit for the amount of bytes scanned (cutoff) per query, if it is specified, and whether workgroup's settings (specified with EnforceWorkGroupConfiguration) in the WorkGroupConfiguration override client-side settings. See WorkGroupConfiguration$EnforceWorkGroupConfiguration. Defaults to None.
        description(str, optional): The workgroup description. Defaults to None.
        tags(List, optional): A list of comma separated tags to add to the workgroup that is created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.work_group.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.work_group.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="create_work_group",
        op_kwargs={
            "Name": name,
            "Configuration": configuration,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(
    hub, ctx, work_group: str, recursive_delete_option: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the workgroup with the specified name. The primary workgroup cannot be deleted.

    Args:
        work_group(str): The unique name of the workgroup to delete.
        recursive_delete_option(bool, optional): The option to delete the workgroup and its contents even if the workgroup contains any named queries or query executions. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.work_group.delete(ctx, work_group=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.work_group.delete work_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="delete_work_group",
        op_kwargs={
            "WorkGroup": work_group,
            "RecursiveDeleteOption": recursive_delete_option,
        },
    )


async def get(hub, ctx, work_group: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the workgroup with the specified name.

    Args:
        work_group(str): The name of the workgroup.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.work_group.get(ctx, work_group=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.work_group.get work_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="get_work_group",
        op_kwargs={"WorkGroup": work_group},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists available workgroups for the account.

    Args:
        next_token(str, optional): A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call. Defaults to None.
        max_results(int, optional): The maximum number of workgroups to return in this request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.work_group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.work_group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="list_work_groups",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub,
    ctx,
    work_group: str,
    description: str = None,
    configuration_updates: Dict = None,
    state: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the workgroup with the specified name. The workgroup's name cannot be changed.

    Args:
        work_group(str): The specified workgroup that will be updated.
        description(str, optional): The workgroup description. Defaults to None.
        configuration_updates(Dict, optional): The workgroup configuration that will be updated for the given workgroup. Defaults to None.
        state(str, optional): The workgroup state that will be updated for the given workgroup. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.work_group.update(ctx, work_group=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.work_group.update work_group=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="update_work_group",
        op_kwargs={
            "WorkGroup": work_group,
            "Description": description,
            "ConfigurationUpdates": configuration_updates,
            "State": state,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def confirm(
    hub, ctx, topic_arn: str, token: str, authenticate_on_unsubscribe: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Verifies an endpoint owner's intent to receive messages by validating the token sent to the endpoint by an earlier Subscribe action. If the token is valid, the action creates a new subscription and returns its Amazon Resource Name (ARN). This call requires an AWS signature only when the AuthenticateOnUnsubscribe flag is set to "true".

    Args:
        topic_arn(str): The ARN of the topic for which you wish to confirm a subscription.
        token(str): Short-lived token sent to an endpoint during the Subscribe action.
        authenticate_on_unsubscribe(str, optional): Disallows unauthenticated unsubscribes of the subscription. If the value of this parameter is true and the request has an Amazon Web Services signature, then only the topic owner and the subscription owner can unsubscribe the endpoint. The unsubscribe action requires Amazon Web Services authentication. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.subscription.init.confirm(ctx, topic_arn=value, token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.subscription.init.confirm topic_arn=value, token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="confirm_subscription",
        op_kwargs={
            "TopicArn": topic_arn,
            "Token": token,
            "AuthenticateOnUnsubscribe": authenticate_on_unsubscribe,
        },
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the requester's subscriptions. Each call returns a limited list of subscriptions, up to 100. If there are more subscriptions, a NextToken is also returned. Use the NextToken parameter in a new ListSubscriptions call to get further results. This action is throttled at 30 transactions per second (TPS).

    Args:
        next_token(str, optional): Token returned by the previous ListSubscriptions request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.subscription.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.subscription.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="list_subscriptions",
        op_kwargs={"NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(hub, ctx, resource_id: str, selfservice_permissions: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the self-service WorkSpace management capabilities for your users. For more information, see Enable Self-Service WorkSpace Management Capabilities for Your Users.

    Args:
        resource_id(str): The identifier of the directory.
        selfservice_permissions(Dict): The permissions to enable or disable self-service capabilities.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.selfservice_permission.modify(
                ctx, resource_id=value, selfservice_permissions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.selfservice_permission.modify resource_id=value, selfservice_permissions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="modify_selfservice_permissions",
        op_kwargs={
            "ResourceId": resource_id,
            "SelfservicePermissions": selfservice_permissions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    db_parameter_group_family: str,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the default engine and system parameter information for the cluster database engine. For more information on Amazon Aurora, see  What Is Amazon Aurora? in the Amazon Aurora User Guide.

    Args:
        db_parameter_group_family(str): The name of the DB cluster parameter group family to return engine parameter information for.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeEngineDefaultClusterParameters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.engine_default.cluster_parameter.describe_all(
                ctx, db_parameter_group_family=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.engine_default.cluster_parameter.describe_all db_parameter_group_family=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_engine_default_cluster_parameters",
        op_kwargs={
            "DBParameterGroupFamily": db_parameter_group_family,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, service_name: str, containers: Dict = None, public_endpoint: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a deployment for your Amazon Lightsail container service. A deployment specifies the containers that will be launched on the container service and their settings, such as the ports to open, the environment variables to apply, and the launch command to run. It also specifies the container that will serve as the public endpoint of the deployment and its settings, such as the HTTP or HTTPS port to use, and the health check configuration. You can deploy containers to your container service using container images from a public registry like Docker Hub, or from your local machine. For more information, see Creating container images for your Amazon Lightsail container services in the Amazon Lightsail Developer Guide.

    Args:
        service_name(str): The name of the container service for which to create the deployment.
        containers(Dict, optional): An object that describes the settings of the containers that will be launched on the container service. Defaults to None.
        public_endpoint(Dict, optional): An object that describes the settings of the public endpoint for the container service. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.service.deployment.create(
                ctx, service_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.service.deployment.create service_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_container_service_deployment",
        op_kwargs={
            "serviceName": service_name,
            "containers": containers,
            "publicEndpoint": public_endpoint,
        },
    )


async def get_all(hub, ctx, service_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the deployments for your Amazon Lightsail container service A deployment specifies the settings, such as the ports and launch command, of containers that are deployed to your container service. The deployments are ordered by version in ascending order. The newest version is listed at the top of the response.  A set number of deployments are kept before the oldest one is replaced with the newest one. For more information, see Amazon Lightsail endpoints and quotas in the AWS General Reference.

    Args:
        service_name(str): The name of the container service for which to return deployments.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.service.deployment.get_all(
                ctx, service_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.service.deployment.get_all service_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_container_service_deployments",
        op_kwargs={"serviceName": service_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, registry_ids: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an authorization token. An authorization token represents your IAM authentication credentials and can be used to access any Amazon ECR registry that your IAM principal has access to. The authorization token is valid for 12 hours. The authorizationToken returned is a base64 encoded string that can be decoded and used in a docker login command to authenticate to a registry. The AWS CLI offers an get-login-password command that simplifies the login process. For more information, see Registry Authentication in the Amazon Elastic Container Registry User Guide.

    Args:
        registry_ids(List, optional): A list of AWS account IDs that are associated with the registries for which to get AuthorizationData objects. If you do not specify a registry, the default registry is assumed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.authorization_token.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.authorization_token.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="get_authorization_token",
        op_kwargs={"registryIds": registry_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    instance_type: str,
    description: str = None,
    client_request_token: str = None,
    subnet_id: str = None,
    image_id: str = None,
    automatic_stop_time_minutes: int = None,
    owner_arn: str = None,
    tags: List = None,
    connection_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Cloud9 development environment, launches an Amazon Elastic Compute Cloud (Amazon EC2) instance, and then connects from the instance to the environment.

    Args:
        name(str): The name of the environment to create. This name is visible to other IAM users in the same Amazon Web Services account.
        description(str, optional): The description of the environment to create. Defaults to None.
        client_request_token(str, optional): A unique, case-sensitive string that helps Cloud9 to ensure this operation completes no more than one time. For more information, see Client Tokens in the Amazon EC2 API Reference. Defaults to None.
        instance_type(str): The type of instance to connect to the environment (for example, t2.micro).
        subnet_id(str, optional): The ID of the subnet in Amazon VPC that Cloud9 will use to communicate with the Amazon EC2 instance. Defaults to None.
        image_id(str, optional): The identifier for the Amazon Machine Image (AMI) that's used to create the EC2 instance. To choose an AMI for the instance, you must specify a valid AMI alias or a valid Amazon EC2 Systems Manager (SSM) path. The default AMI is used if the parameter isn't explicitly assigned a value in the request. Because Amazon Linux AMI has ended standard support as of December 31, 2020, we recommend you choose Amazon Linux 2, which includes long term support through 2023.  AMI aliases      Amazon Linux (default): amazonlinux-1-x86_64     Amazon Linux 2: amazonlinux-2-x86_64    Ubuntu 18.04: ubuntu-18.04-x86_64     SSM paths     Amazon Linux (default): resolve:ssm:/aws/service/cloud9/amis/amazonlinux-1-x86_64     Amazon Linux 2: resolve:ssm:/aws/service/cloud9/amis/amazonlinux-2-x86_64    Ubuntu 18.04: resolve:ssm:/aws/service/cloud9/amis/ubuntu-18.04-x86_64   . Defaults to None.
        automatic_stop_time_minutes(int, optional): The number of minutes until the running instance is shut down after the environment has last been used. Defaults to None.
        owner_arn(str, optional): The Amazon Resource Name (ARN) of the environment owner. This ARN can be the ARN of any IAM principal. If this value is not specified, the ARN defaults to this environment's creator. Defaults to None.
        tags(List, optional): An array of key-value pairs that will be associated with the new Cloud9 development environment. Defaults to None.
        connection_type(str, optional): The connection type used for connecting to an Amazon EC2 environment. Valid values are CONNECT_SSH (default) and CONNECT_SSM (connected through Amazon EC2 Systems Manager). For more information, see Accessing no-ingress EC2 instances with Amazon EC2 Systems Manager in the Cloud9 User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloud9.environment.ec2.create(
                ctx, name=value, instance_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloud9.environment.ec2.create name=value, instance_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloud9",
        operation="create_environment_ec2",
        op_kwargs={
            "name": name,
            "description": description,
            "clientRequestToken": client_request_token,
            "instanceType": instance_type,
            "subnetId": subnet_id,
            "imageId": image_id,
            "automaticStopTimeMinutes": automatic_stop_time_minutes,
            "ownerArn": owner_arn,
            "tags": tags,
            "connectionType": connection_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(
    hub,
    ctx,
    instance_id: str,
    contact_flow_id: str,
    participant_details: Dict,
    attributes: Dict = None,
    initial_message: Dict = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Initiates a contact flow to start a new chat for the customer. Response of this API provides a token required to obtain credentials from the CreateParticipantConnection API in the Amazon Connect Participant Service. When a new chat contact is successfully created, clients must subscribe to the participant’s connection for the created chat within 5 minutes. This is achieved by invoking CreateParticipantConnection with WEBSOCKET and CONNECTION_CREDENTIALS.  A 429 error occurs in two situations:   API rate limit is exceeded. API TPS throttling returns a TooManyRequests exception.   The quota for concurrent active chats is exceeded. Active chat throttling returns a LimitExceededException.   For more information about chat, see Chat in the Amazon Connect Administrator Guide.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        contact_flow_id(str): The identifier of the contact flow for initiating the chat. To see the ContactFlowId in the Amazon Connect console user interface, on the navigation menu go to Routing, Contact Flows. Choose the contact flow. On the contact flow page, under the name of the contact flow, choose Show additional flow information. The ContactFlowId is the last part of the ARN, shown here in bold:  arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/contact-flow/846ec553-a005-41c0-8341-xxxxxxxxxxxx .
        attributes(Dict, optional): A custom key-value pair using an attribute map. The attributes are standard Amazon Connect attributes. They can be accessed in contact flows just like any other contact attributes.  There can be up to 32,768 UTF-8 bytes across all key-value pairs per contact. Attribute keys can include only alphanumeric, dash, and underscore characters. Defaults to None.
        participant_details(Dict): Information identifying the participant.
        initial_message(Dict, optional): The initial message to be sent to the newly created chat. Defaults to None.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.chat_contact.start(
                ctx, instance_id=value, contact_flow_id=value, participant_details=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.chat_contact.start instance_id=value, contact_flow_id=value, participant_details=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="start_chat_contact",
        op_kwargs={
            "InstanceId": instance_id,
            "ContactFlowId": contact_flow_id,
            "Attributes": attributes,
            "ParticipantDetails": participant_details,
            "InitialMessage": initial_message,
            "ClientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    cidr_block: str,
    amazon_provided_ipv6_cidr_block: bool = None,
    ipv6_pool: str = None,
    ipv6_cidr_block: str = None,
    dry_run: bool = None,
    instance_tenancy: str = None,
    ipv6_cidr_block_network_border_group: str = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a VPC with the specified IPv4 CIDR block. The smallest VPC you can create uses a /28 netmask (16 IPv4 addresses), and the largest uses a /16 netmask (65,536 IPv4 addresses). For more information about how large to make your VPC, see Your VPC and subnets in the Amazon Virtual Private Cloud User Guide. You can optionally request an IPv6 CIDR block for the VPC. You can request an Amazon-provided IPv6 CIDR block from Amazon's pool of IPv6 addresses, or an IPv6 CIDR block from an IPv6 address pool that you provisioned through bring your own IP addresses (BYOIP). By default, each instance you launch in the VPC has the default DHCP options, which include only a default DNS server that we provide (AmazonProvidedDNS). For more information, see DHCP options sets in the Amazon Virtual Private Cloud User Guide. You can specify the instance tenancy value for the VPC when you create it. You can't change this value for the VPC after you create it. For more information, see Dedicated Instances in the Amazon Elastic Compute Cloud User Guide.

    Args:
        cidr_block(str): The IPv4 network range for the VPC, in CIDR notation. For example, 10.0.0.0/16. We modify the specified CIDR block to its canonical form; for example, if you specify 100.68.0.18/18, we modify it to 100.68.0.0/18.
        amazon_provided_ipv6_cidr_block(bool, optional): Requests an Amazon-provided IPv6 CIDR block with a /56 prefix length for the VPC. You cannot specify the range of IP addresses, or the size of the CIDR block. Defaults to None.
        ipv6_pool(str, optional): The ID of an IPv6 address pool from which to allocate the IPv6 CIDR block. Defaults to None.
        ipv6_cidr_block(str, optional): The IPv6 CIDR block from the IPv6 address pool. You must also specify Ipv6Pool in the request. To let Amazon choose the IPv6 CIDR block for you, omit this parameter. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_tenancy(str, optional): The tenancy options for instances launched into the VPC. For default, instances are launched with shared tenancy by default. You can launch instances with any tenancy into a shared tenancy VPC. For dedicated, instances are launched as dedicated tenancy instances by default. You can only launch instances with a tenancy of dedicated or host into a dedicated tenancy VPC.   Important: The host value cannot be used with this parameter. Use the default or dedicated values only. Default: default . Defaults to None.
        ipv6_cidr_block_network_border_group(str, optional): The name of the location from which we advertise the IPV6 CIDR block. Use this parameter to limit the address to this location.  You must set AmazonProvidedIpv6CidrBlock to true to use this parameter. Defaults to None.
        tag_specifications(List, optional): The tags to assign to the VPC. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.init.create(ctx, cidr_block=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.init.create cidr_block=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_vpc",
        op_kwargs={
            "CidrBlock": cidr_block,
            "AmazonProvidedIpv6CidrBlock": amazon_provided_ipv6_cidr_block,
            "Ipv6Pool": ipv6_pool,
            "Ipv6CidrBlock": ipv6_cidr_block,
            "DryRun": dry_run,
            "InstanceTenancy": instance_tenancy,
            "Ipv6CidrBlockNetworkBorderGroup": ipv6_cidr_block_network_border_group,
            "TagSpecifications": tag_specifications,
        },
    )


async def delete(hub, ctx, vpc_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified VPC. You must detach or delete all gateways and resources that are associated with the VPC before you can delete it. For example, you must terminate all instances running in the VPC, delete all security groups associated with the VPC (except the default one), delete all route tables associated with the VPC (except the default one), and so on.

    Args:
        vpc_id(str): The ID of the VPC.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.init.delete(ctx, vpc_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.init.delete vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_vpc",
        op_kwargs={"VpcId": vpc_id, "DryRun": dry_run},
    )


async def describe_all(hub, ctx) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified VPC. You must detach or delete all gateways and resources that are associated with the VPC before you can delete it. For example, you must terminate all instances running in the VPC, delete all security groups associated with the VPC (except the default one), delete all route tables associated with the VPC (except the default one), and so on.

    Args:
        vpc_id(str): The ID of the VPC.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.init.delete(ctx, vpc_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.init.delete vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_vpcs",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, reserved_node_id: str, max_records: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of DC2 ReservedNodeOfferings that matches the payment type, term, and usage price of the given DC1 reserved node.

    Args:
        reserved_node_id(str): A string representing the node identifier for the DC1 Reserved Node to be exchanged.
        max_records(int, optional): An integer setting the maximum number of ReservedNodeOfferings to retrieve. Defaults to None.
        marker(str, optional): A value that indicates the starting point for the next set of ReservedNodeOfferings. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.reserved_node.exchange.offering.get_all(
                ctx, reserved_node_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.reserved_node.exchange.offering.get_all reserved_node_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="get_reserved_node_exchange_offerings",
        op_kwargs={
            "ReservedNodeId": reserved_node_id,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the lifecycle configuration from the specified bucket. Amazon S3 removes all the lifecycle configuration rules in the lifecycle subresource associated with the bucket. Your objects never expire, and Amazon S3 no longer automatically deletes any objects on the basis of rules contained in the deleted lifecycle configuration. To use this operation, you must have permission to perform the s3:PutLifecycleConfiguration action. By default, the bucket owner has this permission and the bucket owner can grant this permission to others. There is usually some time lag before lifecycle configuration deletion is fully propagated to all the Amazon S3 systems. For more information about the object expiration, see Elements to Describe Lifecycle Actions. Related actions include:    PutBucketLifecycleConfiguration     GetBucketLifecycleConfiguration

    Args:
        bucket(str): The bucket name of the lifecycle to delete.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.lifecycle.init.delete(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.lifecycle.init.delete bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_bucket_lifecycle",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

     For an updated version of this API, see GetBucketLifecycleConfiguration. If you configured a bucket lifecycle using the filter element, you should see the updated version of this topic. This topic is provided for backward compatibility.  Returns the lifecycle configuration information set on the bucket. For information about lifecycle configuration, see Object Lifecycle Management.  To use this operation, you must have permission to perform the s3:GetLifecycleConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources.  GetBucketLifecycle has the following special error:   Error code: NoSuchLifecycleConfiguration    Description: The lifecycle configuration does not exist.   HTTP Status Code: 404 Not Found   SOAP Fault Code Prefix: Client     The following operations are related to GetBucketLifecycle:    GetBucketLifecycleConfiguration     PutBucketLifecycle     DeleteBucketLifecycle

    Args:
        bucket(str): The name of the bucket for which to get the lifecycle information.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.lifecycle.init.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.lifecycle.init.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_lifecycle",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    content_md5: str = None,
    lifecycle_configuration: Dict = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

     For an updated version of this API, see PutBucketLifecycleConfiguration. This version has been deprecated. Existing lifecycle configurations will work. For new lifecycle configurations, use the updated API.   Creates a new lifecycle configuration for the bucket or replaces an existing lifecycle configuration. For information about lifecycle configuration, see Object Lifecycle Management in the Amazon S3 User Guide.  By default, all Amazon S3 resources, including buckets, objects, and related subresources (for example, lifecycle configuration and website configuration) are private. Only the resource owner, the AWS account that created the resource, can access it. The resource owner can optionally grant access permissions to others by writing an access policy. For this operation, users must get the s3:PutLifecycleConfiguration permission. You can also explicitly deny permissions. Explicit denial also supersedes any other permissions. If you want to prevent users or accounts from removing or deleting objects from your bucket, you must deny them permissions for the following actions:     s3:DeleteObject     s3:DeleteObjectVersion     s3:PutLifecycleConfiguration    For more information about permissions, see Managing Access Permissions to your Amazon S3 Resources in the Amazon S3 User Guide. For more examples of transitioning objects to storage classes such as STANDARD_IA or ONEZONE_IA, see Examples of Lifecycle Configuration.  Related Resources     GetBucketLifecycle(Deprecated)    GetBucketLifecycleConfiguration     RestoreObject    By default, a resource owner—in this case, a bucket owner, which is the AWS account that created the bucket—can perform any of the operations. A resource owner can also grant others permission to perform the operation. For more information, see the following topics in the Amazon S3 User Guide:     Specifying Permissions in a Policy     Managing Access Permissions to your Amazon S3 Resources

    Args:
        bucket(str): .
        content_md5(str, optional):  For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        lifecycle_configuration(Dict, optional): . Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.lifecycle.init.put(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.lifecycle.init.put bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_lifecycle",
        op_kwargs={
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "LifecycleConfiguration": lifecycle_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    network_id: str,
    proposal_id: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the list of votes for a specified proposal, including the value of each vote and the unique identifier of the member that cast the vote. Applies only to Hyperledger Fabric.

    Args:
        network_id(str):  The unique identifier of the network. .
        proposal_id(str):  The unique identifier of the proposal. .
        max_results(int, optional):  The maximum number of votes to return. . Defaults to None.
        next_token(str, optional):  The pagination token that indicates the next set of results to retrieve. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.proposal.vote.list_all(
                ctx, network_id=value, proposal_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.proposal.vote.list_all network_id=value, proposal_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="list_proposal_votes",
        op_kwargs={
            "NetworkId": network_id,
            "ProposalId": proposal_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    cluster_arn: str,
    current_version: str,
    enhanced_monitoring: str = None,
    open_monitoring: Dict = None,
    logging_info: Dict = None,
) -> Dict:
    r"""
        **Autogenerated function**


        Updates the monitoring settings for the cluster. You can use this operation to specify which Apache Kafka metrics you want Amazon MSK to send to Amazon CloudWatch. You can also specify settings for open monitoring with Prometheus.


        Args:
            cluster_arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies the cluster.
    .
            current_version(str):
    The version of the MSK cluster to update. Cluster versions aren't simple numbers. You can describe an MSK cluster to find its version. When this update operation is successful, it generates a new cluster version.
    .
            enhanced_monitoring(str, optional):
    Specifies which Apache Kafka metrics Amazon MSK gathers and sends to Amazon CloudWatch for this cluster.
    . Defaults to None.
            open_monitoring(Dict, optional):
    The settings for open monitoring.
    . Defaults to None.
            logging_info(Dict, optional): . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.monitoring.update(
                    ctx, cluster_arn=value, current_version=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.monitoring.update cluster_arn=value, current_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="update_monitoring",
        op_kwargs={
            "ClusterArn": cluster_arn,
            "CurrentVersion": current_version,
            "EnhancedMonitoring": enhanced_monitoring,
            "OpenMonitoring": open_monitoring,
            "LoggingInfo": logging_info,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    dataset_name: str,
    actions: List,
    triggers: List = None,
    content_delivery_rules: List = None,
    retention_period: Dict = None,
    versioning_configuration: Dict = None,
    tags: List = None,
    late_data_rules: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Used to create a dataset. A dataset stores data retrieved from a data store by applying a queryAction (a SQL query) or a containerAction (executing a containerized application). This operation creates the skeleton of a dataset. The dataset can be populated manually by calling CreateDatasetContent or automatically according to a trigger you specify.

    Args:
        dataset_name(str): The name of the dataset.
        actions(List): A list of actions that create the dataset contents.
        triggers(List, optional): A list of triggers. A trigger causes dataset contents to be populated at a specified time interval or when another dataset's contents are created. The list of triggers can be empty or contain up to five DataSetTrigger objects. Defaults to None.
        content_delivery_rules(List, optional): When dataset contents are created, they are delivered to destinations specified here. Defaults to None.
        retention_period(Dict, optional): Optional. How long, in days, versions of dataset contents are kept for the dataset. If not specified or set to null, versions of dataset contents are retained for at most 90 days. The number of versions of dataset contents retained is determined by the versioningConfiguration parameter. For more information, see  Keeping Multiple Versions of IoT Analytics datasets in the IoT Analytics User Guide. Defaults to None.
        versioning_configuration(Dict, optional): Optional. How many versions of dataset contents are kept. If not specified or set to null, only the latest version plus the latest succeeded version (if they are different) are kept for the time period specified by the retentionPeriod parameter. For more information, see Keeping Multiple Versions of IoT Analytics datasets in the IoT Analytics User Guide. Defaults to None.
        tags(List, optional): Metadata which can be used to manage the dataset. Defaults to None.
        late_data_rules(List, optional): A list of data rules that send notifications to CloudWatch, when data arrives late. To specify lateDataRules, the dataset must use a DeltaTimer filter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.dataset.init.create(
                ctx, dataset_name=value, actions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.dataset.init.create dataset_name=value, actions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="create_dataset",
        op_kwargs={
            "datasetName": dataset_name,
            "actions": actions,
            "triggers": triggers,
            "contentDeliveryRules": content_delivery_rules,
            "retentionPeriod": retention_period,
            "versioningConfiguration": versioning_configuration,
            "tags": tags,
            "lateDataRules": late_data_rules,
        },
    )


async def delete(hub, ctx, dataset_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified dataset. You do not have to delete the content of the dataset before you perform this operation.

    Args:
        dataset_name(str): The name of the dataset to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.dataset.init.delete(ctx, dataset_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.dataset.init.delete dataset_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="delete_dataset",
        op_kwargs={"datasetName": dataset_name},
    )


async def describe(hub, ctx, dataset_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a dataset.

    Args:
        dataset_name(str): The name of the dataset whose information is retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.dataset.init.describe(ctx, dataset_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.dataset.init.describe dataset_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="describe_dataset",
        op_kwargs={"datasetName": dataset_name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about datasets.

    Args:
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this request. The default value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.dataset.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.dataset.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="list_datasets",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    dataset_name: str,
    actions: List,
    triggers: List = None,
    content_delivery_rules: List = None,
    retention_period: Dict = None,
    versioning_configuration: Dict = None,
    late_data_rules: List = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates the settings of a dataset.

    Args:
        dataset_name(str): The name of the dataset to update.
        actions(List): A list of DatasetAction objects.
        triggers(List, optional): A list of DatasetTrigger objects. The list can be empty or can contain up to five DatasetTrigger objects. Defaults to None.
        content_delivery_rules(List, optional): When dataset contents are created, they are delivered to destinations specified here. Defaults to None.
        retention_period(Dict, optional): How long, in days, dataset contents are kept for the dataset. Defaults to None.
        versioning_configuration(Dict, optional): Optional. How many versions of dataset contents are kept. If not specified or set to null, only the latest version plus the latest succeeded version (if they are different) are kept for the time period specified by the retentionPeriod parameter. For more information, see Keeping Multiple Versions of IoT Analytics datasets in the IoT Analytics User Guide. Defaults to None.
        late_data_rules(List, optional): A list of data rules that send notifications to CloudWatch, when data arrives late. To specify lateDataRules, the dataset must use a DeltaTimer filter. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.dataset.init.update(
                ctx, dataset_name=value, actions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.dataset.init.update dataset_name=value, actions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="update_dataset",
        op_kwargs={
            "datasetName": dataset_name,
            "actions": actions,
            "triggers": triggers,
            "contentDeliveryRules": content_delivery_rules,
            "retentionPeriod": retention_period,
            "versioningConfiguration": versioning_configuration,
            "lateDataRules": late_data_rules,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    assessment_target_arn: str,
    assessment_template_name: str,
    duration_in_seconds: int,
    rules_package_arns: List,
    user_attributes_for_findings: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an assessment template for the assessment target that is specified by the ARN of the assessment target. If the service-linked role isn’t already registered, this action also creates and registers a service-linked role to grant Amazon Inspector access to AWS Services needed to perform security assessments.

    Args:
        assessment_target_arn(str): The ARN that specifies the assessment target for which you want to create the assessment template.
        assessment_template_name(str): The user-defined name that identifies the assessment template that you want to create. You can create several assessment templates for an assessment target. The names of the assessment templates that correspond to a particular assessment target must be unique.
        duration_in_seconds(int): The duration of the assessment run in seconds.
        rules_package_arns(List): The ARNs that specify the rules packages that you want to attach to the assessment template.
        user_attributes_for_findings(List, optional): The user-defined attributes that are assigned to every finding that is generated by the assessment run that uses this assessment template. An attribute is a key and value pair (an Attribute object). Within an assessment template, each key must be unique. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.template.create(
                ctx,
                assessment_target_arn=value,
                assessment_template_name=value,
                duration_in_seconds=value,
                rules_package_arns=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.template.create assessment_target_arn=value, assessment_template_name=value, duration_in_seconds=value, rules_package_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="create_assessment_template",
        op_kwargs={
            "assessmentTargetArn": assessment_target_arn,
            "assessmentTemplateName": assessment_template_name,
            "durationInSeconds": duration_in_seconds,
            "rulesPackageArns": rules_package_arns,
            "userAttributesForFindings": user_attributes_for_findings,
        },
    )


async def delete(hub, ctx, assessment_template_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the assessment template that is specified by the ARN of the assessment template.

    Args:
        assessment_template_arn(str): The ARN that specifies the assessment template that you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.template.delete(
                ctx, assessment_template_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.template.delete assessment_template_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="delete_assessment_template",
        op_kwargs={"assessmentTemplateArn": assessment_template_arn},
    )


async def describe_all(hub, ctx, assessment_template_arns: List) -> Dict:
    r"""
    **Autogenerated function**

    Describes the assessment templates that are specified by the ARNs of the assessment templates.

    Args:
        assessment_template_arns(List): .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.template.describe_all(
                ctx, assessment_template_arns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.template.describe_all assessment_template_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="describe_assessment_templates",
        op_kwargs={"assessmentTemplateArns": assessment_template_arns},
    )


async def list_all(
    hub,
    ctx,
    assessment_target_arns: List = None,
    filter_: Dict = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the assessment templates that correspond to the assessment targets that are specified by the ARNs of the assessment targets.

    Args:
        assessment_target_arns(List, optional): A list of ARNs that specifies the assessment targets whose assessment templates you want to list. Defaults to None.
        filter_(Dict, optional): You can use this parameter to specify a subset of data to be included in the action's response. For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match. Defaults to None.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListAssessmentTemplates action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.template.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.template.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="list_assessment_templates",
        op_kwargs={
            "assessmentTargetArns": assessment_target_arns,
            "filter": filter_,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def remove(hub, ctx, resource_name: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes metadata tags from an Amazon Neptune resource.

    Args:
        resource_name(str): The Amazon Neptune resource that the tags are removed from. This value is an Amazon Resource Name (ARN). For information about creating an ARN, see  Constructing an Amazon Resource Name (ARN).
        tag_keys(List): The tag key (name) of the tag to be removed.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.tags.from_resource.remove(
                ctx, resource_name=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.tags.from_resource.remove resource_name=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="remove_tags_from_resource",
        op_kwargs={"ResourceName": resource_name, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def retry(hub, ctx, source_server_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Causes the data replication initiation sequence to begin immediately upon next Handshake for specified SourceServer IDs, regardless of when the previous initiation started. This command will not work if the SourceServer is not stalled or is in a DISCONNECTED or STOPPED state.

    Args:
        source_server_id(str): Retry data replication for Source Server ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.data_replication.retry(ctx, source_server_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.data_replication.retry source_server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="retry_data_replication",
        op_kwargs={"sourceServerID": source_server_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    dataset_name: str,
    name: str,
    output_location: Dict,
    role_arn: str,
    encryption_key_arn: str = None,
    encryption_mode: str = None,
    log_subscription: str = None,
    max_capacity: int = None,
    max_retries: int = None,
    configuration: Dict = None,
    tags: Dict = None,
    timeout: int = None,
    job_sample: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new job to analyze a dataset and create its data profile.

    Args:
        dataset_name(str): The name of the dataset that this job is to act upon.
        encryption_key_arn(str, optional): The Amazon Resource Name (ARN) of an encryption key that is used to protect the job. Defaults to None.
        encryption_mode(str, optional): The encryption mode for the job, which can be one of the following:    SSE-KMS - SSE-KMS - Server-side encryption with KMS-managed keys.    SSE-S3 - Server-side encryption with keys managed by Amazon S3.  . Defaults to None.
        name(str): The name of the job to be created. Valid characters are alphanumeric (A-Z, a-z, 0-9), hyphen (-), period (.), and space.
        log_subscription(str, optional): Enables or disables Amazon CloudWatch logging for the job. If logging is enabled, CloudWatch writes one log stream for each job run. Defaults to None.
        max_capacity(int, optional): The maximum number of nodes that DataBrew can use when the job processes data. Defaults to None.
        max_retries(int, optional): The maximum number of times to retry the job after a job run fails. Defaults to None.
        output_location(Dict): Represents an Amazon S3 location (bucket name and object key) where DataBrew can read input data, or write output from a job.
        configuration(Dict, optional): Configuration for profile jobs. Used to select columns, do evaluations, and override default parameters of evaluations. When configuration is null, the profile job will run with default settings. Defaults to None.
        role_arn(str): The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role to be assumed when DataBrew runs the job.
        tags(Dict, optional): Metadata tags to apply to this job. Defaults to None.
        timeout(int, optional): The job's timeout in minutes. A job that attempts to run longer than this timeout period ends with a status of TIMEOUT. Defaults to None.
        job_sample(Dict, optional): Sample configuration for profile jobs only. Determines the number of rows on which the profile job will be executed. If a JobSample value is not provided, the default value will be used. The default value is CUSTOM_ROWS for the mode parameter and 20000 for the size parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.profile_job.create(
                ctx, dataset_name=value, name=value, output_location=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.profile_job.create dataset_name=value, name=value, output_location=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="create_profile_job",
        op_kwargs={
            "DatasetName": dataset_name,
            "EncryptionKeyArn": encryption_key_arn,
            "EncryptionMode": encryption_mode,
            "Name": name,
            "LogSubscription": log_subscription,
            "MaxCapacity": max_capacity,
            "MaxRetries": max_retries,
            "OutputLocation": output_location,
            "Configuration": configuration,
            "RoleArn": role_arn,
            "Tags": tags,
            "Timeout": timeout,
            "JobSample": job_sample,
        },
    )


async def update(
    hub,
    ctx,
    name: str,
    output_location: Dict,
    role_arn: str,
    configuration: Dict = None,
    encryption_key_arn: str = None,
    encryption_mode: str = None,
    log_subscription: str = None,
    max_capacity: int = None,
    max_retries: int = None,
    timeout: int = None,
    job_sample: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the definition of an existing profile job.

    Args:
        configuration(Dict, optional): Configuration for profile jobs. Used to select columns, do evaluations, and override default parameters of evaluations. When configuration is null, the profile job will run with default settings. Defaults to None.
        encryption_key_arn(str, optional): The Amazon Resource Name (ARN) of an encryption key that is used to protect the job. Defaults to None.
        encryption_mode(str, optional): The encryption mode for the job, which can be one of the following:    SSE-KMS - Server-side encryption with keys managed by KMS.    SSE-S3 - Server-side encryption with keys managed by Amazon S3.  . Defaults to None.
        name(str): The name of the job to be updated.
        log_subscription(str, optional): Enables or disables Amazon CloudWatch logging for the job. If logging is enabled, CloudWatch writes one log stream for each job run. Defaults to None.
        max_capacity(int, optional): The maximum number of compute nodes that DataBrew can use when the job processes data. Defaults to None.
        max_retries(int, optional): The maximum number of times to retry the job after a job run fails. Defaults to None.
        output_location(Dict): Represents an Amazon S3 location (bucket name and object key) where DataBrew can read input data, or write output from a job.
        role_arn(str): The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role to be assumed when DataBrew runs the job.
        timeout(int, optional): The job's timeout in minutes. A job that attempts to run longer than this timeout period ends with a status of TIMEOUT. Defaults to None.
        job_sample(Dict, optional): Sample configuration for Profile Jobs only. Determines the number of rows on which the Profile job will be executed. If a JobSample value is not provided for profile jobs, the default value will be used. The default value is CUSTOM_ROWS for the mode parameter and 20000 for the size parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.profile_job.update(
                ctx, name=value, output_location=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.profile_job.update name=value, output_location=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="update_profile_job",
        op_kwargs={
            "Configuration": configuration,
            "EncryptionKeyArn": encryption_key_arn,
            "EncryptionMode": encryption_mode,
            "Name": name,
            "LogSubscription": log_subscription,
            "MaxCapacity": max_capacity,
            "MaxRetries": max_retries,
            "OutputLocation": output_location,
            "RoleArn": role_arn,
            "Timeout": timeout,
            "JobSample": job_sample,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, group_id: str, amzn_client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a CA for the group. If a CA already exists, it will rotate the existing CA.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        group_id(str): The ID of the Greengrass group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.group.certificate.authority.create(
                ctx, group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.group.certificate.authority.create group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="create_group_certificate_authority",
        op_kwargs={"AmznClientToken": amzn_client_token, "GroupId": group_id},
    )


async def get(hub, ctx, certificate_authority_id: str, group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retreives the CA associated with a group. Returns the public key of the CA.

    Args:
        certificate_authority_id(str): The ID of the certificate authority.
        group_id(str): The ID of the Greengrass group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.group.certificate.authority.get(
                ctx, certificate_authority_id=value, group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.group.certificate.authority.get certificate_authority_id=value, group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_group_certificate_authority",
        op_kwargs={
            "CertificateAuthorityId": certificate_authority_id,
            "GroupId": group_id,
        },
    )


async def list_all(hub, ctx, group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the current CAs for a group.

    Args:
        group_id(str): The ID of the Greengrass group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.group.certificate.authority.list_all(
                ctx, group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.group.certificate.authority.list_all group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_group_certificate_authorities",
        op_kwargs={"GroupId": group_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(hub, ctx, elastic_ip: str, instance_id: str = None) -> None:
    r"""
    **Autogenerated function**

    Associates one of the stack's registered Elastic IP addresses with a specified instance. The address must first be registered with the stack by calling RegisterElasticIp. For more information, see Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        elastic_ip(str): The Elastic IP address.
        instance_id(str, optional): The instance ID. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.elastic.ip.associate(ctx, elastic_ip=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.elastic.ip.associate elastic_ip=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="associate_elastic_ip",
        op_kwargs={"ElasticIp": elastic_ip, "InstanceId": instance_id},
    )


async def deregister(hub, ctx, elastic_ip: str) -> None:
    r"""
    **Autogenerated function**

    Deregisters a specified Elastic IP address. The address can then be registered by another stack. For more information, see Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        elastic_ip(str): The Elastic IP address.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.elastic.ip.deregister(ctx, elastic_ip=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.elastic.ip.deregister elastic_ip=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="deregister_elastic_ip",
        op_kwargs={"ElasticIp": elastic_ip},
    )


async def describe_all(
    hub, ctx, instance_id: str = None, stack_id: str = None, ips: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes Elastic IP addresses.  This call accepts only one resource-identifying parameter.   Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        instance_id(str, optional): The instance ID. If you include this parameter, DescribeElasticIps returns a description of the Elastic IP addresses associated with the specified instance. Defaults to None.
        stack_id(str, optional): A stack ID. If you include this parameter, DescribeElasticIps returns a description of the Elastic IP addresses that are registered with the specified stack. Defaults to None.
        ips(List, optional): An array of Elastic IP addresses to be described. If you include this parameter, DescribeElasticIps returns a description of the specified Elastic IP addresses. Otherwise, it returns a description of every Elastic IP address. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.elastic.ip.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.elastic.ip.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_elastic_ips",
        op_kwargs={"InstanceId": instance_id, "StackId": stack_id, "Ips": ips},
    )


async def disassociate(hub, ctx, elastic_ip: str) -> None:
    r"""
    **Autogenerated function**

    Disassociates an Elastic IP address from its instance. The address remains registered with the stack. For more information, see Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        elastic_ip(str): The Elastic IP address.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.elastic.ip.disassociate(ctx, elastic_ip=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.elastic.ip.disassociate elastic_ip=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="disassociate_elastic_ip",
        op_kwargs={"ElasticIp": elastic_ip},
    )


async def register(hub, ctx, elastic_ip: str, stack_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Registers an Elastic IP address with a specified stack. An address can be registered with only one stack at a time. If the address is already registered, you must first deregister it by calling DeregisterElasticIp. For more information, see Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        elastic_ip(str): The Elastic IP address.
        stack_id(str): The stack ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.elastic.ip.register(
                ctx, elastic_ip=value, stack_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.elastic.ip.register elastic_ip=value, stack_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="register_elastic_ip",
        op_kwargs={"ElasticIp": elastic_ip, "StackId": stack_id},
    )


async def update(hub, ctx, elastic_ip: str, name: str = None) -> None:
    r"""
    **Autogenerated function**

    Updates a registered Elastic IP address's name. For more information, see Resource Management.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        elastic_ip(str): The IP address for which you want to update the name.
        name(str, optional): The new name. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.elastic.ip.update(ctx, elastic_ip=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.elastic.ip.update elastic_ip=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="update_elastic_ip",
        op_kwargs={"ElasticIp": elastic_ip, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    organization_id: str,
    group_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an overview of the members of a group. Users and groups can be members of a group.

    Args:
        organization_id(str): The identifier for the organization under which the group exists.
        group_id(str): The identifier for the group to which the members (users or groups) are associated.
        next_token(str, optional):  The token to use to retrieve the next page of results. The first call does not contain any tokens. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.group.member.list_all(
                ctx, organization_id=value, group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.group.member.list_all organization_id=value, group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="list_group_members",
        op_kwargs={
            "OrganizationId": organization_id,
            "GroupId": group_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    direct_connect_gateway_id: str,
    gateway_id: str = None,
    add_allowed_prefixes_to_direct_connect_gateway: List = None,
    virtual_gateway_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an association between a Direct Connect gateway and a virtual private gateway. The virtual private gateway must be attached to a VPC and must not be associated with another Direct Connect gateway.

    Args:
        direct_connect_gateway_id(str): The ID of the Direct Connect gateway.
        gateway_id(str, optional): The ID of the virtual private gateway or transit gateway. Defaults to None.
        add_allowed_prefixes_to_direct_connect_gateway(List, optional): The Amazon VPC prefixes to advertise to the Direct Connect gateway This parameter is required when you create an association to a transit gateway. For information about how to set the prefixes, see Allowed Prefixes in the Direct Connect User Guide. Defaults to None.
        virtual_gateway_id(str, optional): The ID of the virtual private gateway. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.direct_connect_gateway.association.init.create(
                ctx, direct_connect_gateway_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.direct_connect_gateway.association.init.create direct_connect_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="create_direct_connect_gateway_association",
        op_kwargs={
            "directConnectGatewayId": direct_connect_gateway_id,
            "gatewayId": gateway_id,
            "addAllowedPrefixesToDirectConnectGateway": add_allowed_prefixes_to_direct_connect_gateway,
            "virtualGatewayId": virtual_gateway_id,
        },
    )


async def delete(
    hub,
    ctx,
    association_id: str = None,
    direct_connect_gateway_id: str = None,
    virtual_gateway_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the association between the specified Direct Connect gateway and virtual private gateway. We recommend that you specify the associationID to delete the association. Alternatively, if you own virtual gateway and a Direct Connect gateway association, you can specify the virtualGatewayId and directConnectGatewayId to delete an association.

    Args:
        association_id(str, optional): The ID of the Direct Connect gateway association. Defaults to None.
        direct_connect_gateway_id(str, optional): The ID of the Direct Connect gateway. Defaults to None.
        virtual_gateway_id(str, optional): The ID of the virtual private gateway. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.direct_connect_gateway.association.init.delete(
                ctx
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.direct_connect_gateway.association.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="delete_direct_connect_gateway_association",
        op_kwargs={
            "associationId": association_id,
            "directConnectGatewayId": direct_connect_gateway_id,
            "virtualGatewayId": virtual_gateway_id,
        },
    )


async def describe_all(
    hub,
    ctx,
    association_id: str = None,
    associated_gateway_id: str = None,
    direct_connect_gateway_id: str = None,
    max_results: int = None,
    next_token: str = None,
    virtual_gateway_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the associations between your Direct Connect gateways and virtual private gateways and transit gateways. You must specify one of the following:   A Direct Connect gateway The response contains all virtual private gateways and transit gateways associated with the Direct Connect gateway.   A virtual private gateway The response contains the Direct Connect gateway.   A transit gateway The response contains the Direct Connect gateway.   A Direct Connect gateway and a virtual private gateway The response contains the association between the Direct Connect gateway and virtual private gateway.   A Direct Connect gateway and a transit gateway The response contains the association between the Direct Connect gateway and transit gateway.

    Args:
        association_id(str, optional): The ID of the Direct Connect gateway association. Defaults to None.
        associated_gateway_id(str, optional): The ID of the associated gateway. Defaults to None.
        direct_connect_gateway_id(str, optional): The ID of the Direct Connect gateway. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. If MaxResults is given a value larger than 100, only 100 results are returned. Defaults to None.
        next_token(str, optional): The token provided in the previous call to retrieve the next page. Defaults to None.
        virtual_gateway_id(str, optional): The ID of the virtual private gateway or transit gateway. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.direct_connect_gateway.association.init.describe_all(
                ctx
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.direct_connect_gateway.association.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="describe_direct_connect_gateway_associations",
        op_kwargs={
            "associationId": association_id,
            "associatedGatewayId": associated_gateway_id,
            "directConnectGatewayId": direct_connect_gateway_id,
            "maxResults": max_results,
            "nextToken": next_token,
            "virtualGatewayId": virtual_gateway_id,
        },
    )


async def update(
    hub,
    ctx,
    association_id: str = None,
    add_allowed_prefixes_to_direct_connect_gateway: List = None,
    remove_allowed_prefixes_to_direct_connect_gateway: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified attributes of the Direct Connect gateway association. Add or remove prefixes from the association.

    Args:
        association_id(str, optional): The ID of the Direct Connect gateway association. Defaults to None.
        add_allowed_prefixes_to_direct_connect_gateway(List, optional): The Amazon VPC prefixes to advertise to the Direct Connect gateway. Defaults to None.
        remove_allowed_prefixes_to_direct_connect_gateway(List, optional): The Amazon VPC prefixes to no longer advertise to the Direct Connect gateway. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.direct_connect_gateway.association.init.update(
                ctx
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.direct_connect_gateway.association.init.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="update_direct_connect_gateway_association",
        op_kwargs={
            "associationId": association_id,
            "addAllowedPrefixesToDirectConnectGateway": add_allowed_prefixes_to_direct_connect_gateway,
            "removeAllowedPrefixesToDirectConnectGateway": remove_allowed_prefixes_to_direct_connect_gateway,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def add(hub, ctx, tags: List, instance_names: List) -> None:
    r"""
    **Autogenerated function**

    Adds tags to on-premises instances.

    Args:
        tags(List): The tag key-value pairs to add to the on-premises instances. Keys and values are both required. Keys cannot be null or empty strings. Value-only tags are not allowed.
        instance_names(List): The names of the on-premises instances to which to add tags.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.tags.to_on_premise_instance.add(
                ctx, tags=value, instance_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.tags.to_on_premise_instance.add tags=value, instance_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="add_tags_to_on_premises_instances",
        op_kwargs={"tags": tags, "instanceNames": instance_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, service_code: str, quota_code: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the applied quota value for the specified quota. For some quotas, only the default values are available. If the applied quota value is not available for a quota, the quota is not retrieved.

    Args:
        service_code(str): The service identifier.
        quota_code(str): The quota identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.service_quotas.service.quota.init.get(
                ctx, service_code=value, quota_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.service_quotas.service.quota.init.get service_code=value, quota_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="service-quotas",
        operation="get_service_quota",
        op_kwargs={"ServiceCode": service_code, "QuotaCode": quota_code},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    directory_id: str,
    computer_name: str,
    password: str,
    organizational_unit_distinguished_name: str = None,
    computer_attributes: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Active Directory computer object in the specified directory.

    Args:
        directory_id(str): The identifier of the directory in which to create the computer account.
        computer_name(str): The name of the computer account.
        password(str): A one-time password that is used to join the computer to the directory. You should generate a random, strong password to use for this parameter.
        organizational_unit_distinguished_name(str, optional): The fully-qualified distinguished name of the organizational unit to place the computer account in. Defaults to None.
        computer_attributes(List, optional): An array of Attribute objects that contain any LDAP attributes to apply to the computer account. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.computer.create(
                ctx, directory_id=value, computer_name=value, password=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.computer.create directory_id=value, computer_name=value, password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="create_computer",
        op_kwargs={
            "DirectoryId": directory_id,
            "ComputerName": computer_name,
            "Password": password,
            "OrganizationalUnitDistinguishedName": organizational_unit_distinguished_name,
            "ComputerAttributes": computer_attributes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def reboot(hub, ctx, cluster_name: str, node_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Reboots a single node of a DAX cluster. The reboot action takes place as soon as possible. During the reboot, the node status is set to REBOOTING.   RebootNode restarts the DAX engine process and does not remove the contents of the cache.

    Args:
        cluster_name(str): The name of the DAX cluster containing the node to be rebooted.
        node_id(str): The system-assigned ID of the node to be rebooted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.node.reboot(ctx, cluster_name=value, node_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.node.reboot cluster_name=value, node_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="reboot_node",
        op_kwargs={"ClusterName": cluster_name, "NodeId": node_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, database_name: str, kms_key_id: str = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Timestream database. If the KMS key is not specified, the database will be encrypted with a Timestream managed KMS key located in your account. Refer to AWS managed KMS keys for more info. Service quotas apply. For more information, see Access Management in the Timestream Developer Guide.

    Args:
        database_name(str): The name of the Timestream database.
        kms_key_id(str, optional): The KMS key for the database. If the KMS key is not specified, the database will be encrypted with a Timestream managed KMS key located in your account. Refer to AWS managed KMS keys for more info. Defaults to None.
        tags(List, optional):  A list of key-value pairs to label the table. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.database.create(ctx, database_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.database.create database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="create_database",
        op_kwargs={"DatabaseName": database_name, "KmsKeyId": kms_key_id, "Tags": tags},
    )


async def delete(hub, ctx, database_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a given Timestream database. This is an irreversible operation. After a database is deleted, the time series data from its tables cannot be recovered.  All tables in the database must be deleted first, or a ValidationException error will be thrown.  Due to the nature of distributed retries, the operation can return either success or a ResourceNotFoundException. Clients should consider them equivalent.

    Args:
        database_name(str): The name of the Timestream database to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.database.delete(ctx, database_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.database.delete database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="delete_database",
        op_kwargs={"DatabaseName": database_name},
    )


async def describe(hub, ctx, database_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the database, including the database name, time that the database was created, and the total number of tables found within the database. Service quotas apply. For more information, see Access Management in the Timestream Developer Guide.

    Args:
        database_name(str): The name of the Timestream database.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.database.describe(ctx, database_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.database.describe database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="describe_database",
        op_kwargs={"DatabaseName": database_name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of your Timestream databases. Service quotas apply. For more information, see Access Management in the Timestream Developer Guide.

    Args:
        next_token(str, optional): The pagination token. To resume pagination, provide the NextToken value as argument of a subsequent API invocation. Defaults to None.
        max_results(int, optional): The total number of items to return in the output. If the total number of items available is more than the value specified, a NextToken is provided in the output. To resume pagination, provide the NextToken value as argument of a subsequent API invocation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.database.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.database.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="list_databases",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(hub, ctx, database_name: str, kms_key_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Modifies the KMS key for an existing database. While updating the database, you must specify the database name and the identifier of the new KMS key to be used (KmsKeyId). If there are any concurrent UpdateDatabase requests, first writer wins.

    Args:
        database_name(str):  The name of the database. .
        kms_key_id(str):  The identifier of the new KMS key (KmsKeyId) to be used to encrypt the data stored in the database. If the KmsKeyId currently registered with the database is the same as the KmsKeyId in the request, there will not be any update.  You can specify the KmsKeyId using any of the following:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-1:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-1:111122223333:alias/ExampleAlias   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_write.database.update(
                ctx, database_name=value, kms_key_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_write.database.update database_name=value, kms_key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-write",
        operation="update_database",
        op_kwargs={"DatabaseName": database_name, "KmsKeyId": kms_key_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete_multiple(hub, ctx, rule_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Permanently deletes the specified Contributor Insights rules. If you create a rule, delete it, and then re-create it with the same name, historical data from the first time the rule was created might not be available.

    Args:
        rule_names(List): An array of the rule names to delete. If you need to find out the names of your rules, use DescribeInsightRules.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.insight_rule.init.delete_multiple(
                ctx, rule_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.insight_rule.init.delete_multiple rule_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="delete_insight_rules",
        op_kwargs={"RuleNames": rule_names},
    )


async def describe_all(
    hub, ctx, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all the Contributor Insights rules in your account. For more information about Contributor Insights, see Using Contributor Insights to Analyze High-Cardinality Data.

    Args:
        next_token(str, optional): Include this value, if it was returned by the previous operation, to get the next set of rules. Defaults to None.
        max_results(int, optional): The maximum number of results to return in one operation. If you omit this parameter, the default of 500 is used. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.insight_rule.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.insight_rule.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="describe_insight_rules",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def disable(hub, ctx, rule_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Disables the specified Contributor Insights rules. When rules are disabled, they do not analyze log groups and do not incur costs.

    Args:
        rule_names(List): An array of the rule names to disable. If you need to find out the names of your rules, use DescribeInsightRules.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.insight_rule.init.disable(ctx, rule_names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.insight_rule.init.disable rule_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="disable_insight_rules",
        op_kwargs={"RuleNames": rule_names},
    )


async def enable(hub, ctx, rule_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Enables the specified Contributor Insights rules. When rules are enabled, they immediately begin analyzing log data.

    Args:
        rule_names(List): An array of the rule names to enable. If you need to find out the names of your rules, use DescribeInsightRules.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.insight_rule.init.enable(ctx, rule_names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.insight_rule.init.enable rule_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="enable_insight_rules",
        op_kwargs={"RuleNames": rule_names},
    )


async def put(
    hub,
    ctx,
    rule_name: str,
    rule_definition: str,
    rule_state: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Contributor Insights rule. Rules evaluate log events in a CloudWatch Logs log group, enabling you to find contributor data for the log events in that log group. For more information, see Using Contributor Insights to Analyze High-Cardinality Data. If you create a rule, delete it, and then re-create it with the same name, historical data from the first time the rule was created might not be available.

    Args:
        rule_name(str): A unique name for the rule.
        rule_state(str, optional): The state of the rule. Valid values are ENABLED and DISABLED. Defaults to None.
        rule_definition(str): The definition of the rule, as a JSON object. For details on the valid syntax, see Contributor Insights Rule Syntax.
        tags(List, optional): A list of key-value pairs to associate with the Contributor Insights rule. You can associate as many as 50 tags with a rule. Tags can help you organize and categorize your resources. You can also use them to scope user permissions, by granting a user permission to access or change only the resources that have certain tag values. To be able to associate tags with a rule, you must have the cloudwatch:TagResource permission in addition to the cloudwatch:PutInsightRule permission. If you are using this operation to update an existing Contributor Insights rule, any tags you specify in this parameter are ignored. To change the tags of an existing rule, use TagResource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.insight_rule.init.put(
                ctx, rule_name=value, rule_definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.insight_rule.init.put rule_name=value, rule_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="put_insight_rule",
        op_kwargs={
            "RuleName": rule_name,
            "RuleState": rule_state,
            "RuleDefinition": rule_definition,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    spot_fleet_request_id: str,
    start_time: str,
    dry_run: bool = None,
    event_type: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the events for the specified Spot Fleet request during the specified time. Spot Fleet events are delayed by up to 30 seconds before they can be described. This ensures that you can query by the last evaluated time and not miss a recorded event. Spot Fleet events are available for 48 hours.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        event_type(str, optional): The type of events to describe. By default, all events are described. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Specify a value between 1 and 1000. The default value is 1000. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        spot_fleet_request_id(str): The ID of the Spot Fleet request.
        start_time(str): The starting date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.spot.fleet.request.history.describe(
                ctx, spot_fleet_request_id=value, start_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.spot.fleet.request.history.describe spot_fleet_request_id=value, start_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_spot_fleet_request_history",
        op_kwargs={
            "DryRun": dry_run,
            "EventType": event_type,
            "MaxResults": max_results,
            "NextToken": next_token,
            "SpotFleetRequestId": spot_fleet_request_id,
            "StartTime": start_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "filter"


async def create(
    hub, ctx, name: str, dataset_group_arn: str, filter_expression: str
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a recommendation filter. For more information, see filter.

    Args:
        name(str): The name of the filter to create.
        dataset_group_arn(str): The ARN of the dataset group that the filter will belong to.
        filter_expression(str): The filter expression defines which items are included or excluded from recommendations. Filter expression must follow specific format rules. For information about filter expression structure and syntax, see filter-expressions.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.filter_.create(
                ctx, name=value, dataset_group_arn=value, filter_expression=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.filter.create name=value, dataset_group_arn=value, filter_expression=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="create_filter",
        op_kwargs={
            "name": name,
            "datasetGroupArn": dataset_group_arn,
            "filterExpression": filter_expression,
        },
    )


async def delete(hub, ctx, filter_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a filter.

    Args:
        filter_arn(str): The ARN of the filter to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.filter_.delete(ctx, filter_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.filter.delete filter_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="delete_filter",
        op_kwargs={"filterArn": filter_arn},
    )


async def describe(hub, ctx, filter_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a filter's properties.

    Args:
        filter_arn(str): The ARN of the filter to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.filter_.describe(ctx, filter_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.filter.describe filter_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="describe_filter",
        op_kwargs={"filterArn": filter_arn},
    )


async def list_all(
    hub,
    ctx,
    dataset_group_arn: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all filters that belong to a given dataset group.

    Args:
        dataset_group_arn(str, optional): The ARN of the dataset group that contains the filters. Defaults to None.
        next_token(str, optional): A token returned from the previous call to ListFilters for getting the next set of filters (if they exist). Defaults to None.
        max_results(int, optional): The maximum number of filters to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.filter_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.filter.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="list_filters",
        op_kwargs={
            "datasetGroupArn": dataset_group_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, domain_name: str, deployed: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the availability options configured for a domain. By default, shows the configuration with any pending changes. Set the Deployed option to true to show the active configuration and exclude pending changes. For more information, see Configuring Availability Options in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): The name of the domain you want to describe.
        deployed(bool, optional): Whether to display the deployed configuration (true) or include any pending changes (false). Defaults to false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.availability_option.describe_all(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.availability_option.describe_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="describe_availability_options",
        op_kwargs={"DomainName": domain_name, "Deployed": deployed},
    )


async def update_multiple(hub, ctx, domain_name: str, multi_az: bool) -> Dict:
    r"""
    **Autogenerated function**

    Configures the availability options for a domain. Enabling the Multi-AZ option expands an Amazon CloudSearch domain to an additional Availability Zone in the same Region to increase fault tolerance in the event of a service disruption. Changes to the Multi-AZ option can take about half an hour to become active. For more information, see Configuring Availability Options in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        multi_az(bool): You expand an existing search domain to a second Availability Zone by setting the Multi-AZ option to true. Similarly, you can turn off the Multi-AZ option to downgrade the domain to a single Availability Zone by setting the Multi-AZ option to false. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.availability_option.update_multiple(
                ctx, domain_name=value, multi_az=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.availability_option.update_multiple domain_name=value, multi_az=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="update_availability_options",
        op_kwargs={"DomainName": domain_name, "MultiAZ": multi_az},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, base_image: str, client_token: str, image_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a version of the SageMaker image specified by ImageName. The version represents the Amazon Container Registry (ECR) container image specified by BaseImage.

    Args:
        base_image(str): The registry path of the container image to use as the starting point for this version. The path is an Amazon Container Registry (ECR) URI in the following format:  <acct-id>.dkr.ecr.<region>.amazonaws.com/<repo-name[:tag] or [@digest]> .
        client_token(str): A unique ID. If not specified, the Amazon Web Services CLI and Amazon Web Services SDKs, such as the SDK for Python (Boto3), add a unique value to the call.
        image_name(str): The ImageName of the Image to create a version of.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.image.version.create(
                ctx, base_image=value, client_token=value, image_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.image.version.create base_image=value, client_token=value, image_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_image_version",
        op_kwargs={
            "BaseImage": base_image,
            "ClientToken": client_token,
            "ImageName": image_name,
        },
    )


async def delete(hub, ctx, image_name: str, version: int) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a version of a SageMaker image. The container image the version represents isn't deleted.

    Args:
        image_name(str): The name of the image.
        version(int): The version to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.image.version.delete(
                ctx, image_name=value, version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.image.version.delete image_name=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_image_version",
        op_kwargs={"ImageName": image_name, "Version": version},
    )


async def describe(hub, ctx, image_name: str, version: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes a version of a SageMaker image.

    Args:
        image_name(str): The name of the image.
        version(int, optional): The version of the image. If not specified, the latest version is described. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.image.version.describe(ctx, image_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.image.version.describe image_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_image_version",
        op_kwargs={"ImageName": image_name, "Version": version},
    )


async def list_all(
    hub,
    ctx,
    image_name: str,
    creation_time_after: str = None,
    creation_time_before: str = None,
    last_modified_time_after: str = None,
    last_modified_time_before: str = None,
    max_results: int = None,
    next_token: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the versions of a specified image and their properties. The list can be filtered by creation time or modified time.

    Args:
        creation_time_after(str, optional): A filter that returns only versions created on or after the specified time. Defaults to None.
        creation_time_before(str, optional): A filter that returns only versions created on or before the specified time. Defaults to None.
        image_name(str): The name of the image to list the versions of.
        last_modified_time_after(str, optional): A filter that returns only versions modified on or after the specified time. Defaults to None.
        last_modified_time_before(str, optional): A filter that returns only versions modified on or before the specified time. Defaults to None.
        max_results(int, optional): The maximum number of versions to return in the response. The default value is 10. . Defaults to None.
        next_token(str, optional): If the previous call to ListImageVersions didn't return the full set of versions, the call returns a token for getting the next set of versions. Defaults to None.
        sort_by(str, optional): The property used to sort results. The default value is CREATION_TIME. Defaults to None.
        sort_order(str, optional): The sort order. The default value is DESCENDING. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.image.version.list_all(ctx, image_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.image.version.list_all image_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_image_versions",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "ImageName": image_name,
            "LastModifiedTimeAfter": last_modified_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "MaxResults": max_results,
            "NextToken": next_token,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the properties associated with an InferRxNorm job. Use this operation to get the status of an inference job.

    Args:
        job_id(str): The identifier that Amazon Comprehend Medical generated for the job. The StartRxNormInferenceJob operation returns this identifier in its response.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehendmedical.rx_norm.inference_job.describe(
                ctx, job_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehendmedical.rx_norm.inference_job.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehendmedical",
        operation="describe_rx_norm_inference_job",
        op_kwargs={"JobId": job_id},
    )


async def list_all(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of InferRxNorm jobs that you have submitted.

    Args:
        filter_(Dict, optional): Filters the jobs that are returned. You can filter jobs based on their names, status, or the date and time that they were submitted. You can only set one filter at a time. Defaults to None.
        next_token(str, optional): Identifies the next page of results to return. Defaults to None.
        max_results(int, optional): Identifies the next page of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehendmedical.rx_norm.inference_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehendmedical.rx_norm.inference_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehendmedical",
        operation="list_rx_norm_inference_jobs",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    input_data_config: Dict,
    output_data_config: Dict,
    data_access_role_arn: str,
    language_code: str,
    job_name: str = None,
    client_request_token: str = None,
    kms_key: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an asynchronous job to detect medication entities and link them to the RxNorm ontology. Use the DescribeRxNormInferenceJob operation to track the status of a job.

    Args:
        input_data_config(Dict): Specifies the format and location of the input data for the job.
        output_data_config(Dict): Specifies where to send the output files.
        data_access_role_arn(str): The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that grants Amazon Comprehend Medical read access to your input data. For more information, see  Role-Based Permissions Required for Asynchronous Operations.
        job_name(str, optional): The identifier of the job. Defaults to None.
        client_request_token(str, optional): A unique identifier for the request. If you don't set the client request token, Amazon Comprehend Medical generates one. Defaults to None.
        kms_key(str, optional): An AWS Key Management Service key to encrypt your output files. If you do not specify a key, the files are written in plain text. Defaults to None.
        language_code(str): The language of the input documents. All documents must be in the same language.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehendmedical.rx_norm.inference_job.start(
                ctx,
                input_data_config=value,
                output_data_config=value,
                data_access_role_arn=value,
                language_code=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehendmedical.rx_norm.inference_job.start input_data_config=value, output_data_config=value, data_access_role_arn=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehendmedical",
        operation="start_rx_norm_inference_job",
        op_kwargs={
            "InputDataConfig": input_data_config,
            "OutputDataConfig": output_data_config,
            "DataAccessRoleArn": data_access_role_arn,
            "JobName": job_name,
            "ClientRequestToken": client_request_token,
            "KMSKey": kms_key,
            "LanguageCode": language_code,
        },
    )


async def stop(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops an InferRxNorm inference job in progress.

    Args:
        job_id(str): The identifier of the job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehendmedical.rx_norm.inference_job.stop(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehendmedical.rx_norm.inference_job.stop job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehendmedical",
        operation="stop_rx_norm_inference_job",
        op_kwargs={"JobId": job_id},
    )
